@@ -94,6 +94,7 @@ Options:
 
 
 def main():
+    enable_pretty_logging()
     command = 'help'
     if len(sys.argv) > 1:
         command = sys.argv[1]
@@ -120,14 +121,14 @@ def main():
             creator.create(arg_settings)
         else:
             g.detail_logging = args['--verbose']
-            enable_pretty_logging()
             generator.build(arg_settings)
     elif command == 'server':
         arg_settings = args['--settings'] or 'settings.py'
         arg_port = int(args['--port'] or 8000)
         if not os.path.exists(arg_settings):
             print('setting file not found')
-            g.output_directory = os.path.abspath('.')
+            server.config(arg_port)
+            server.start_server()
         else:
             generator.load_settings(arg_settings)
         if settings.permalink.endswith('.html'):
